@@ -46,7 +46,7 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCaptchaData(self, request):
@@ -69,7 +69,7 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCaptchaDataSum(self, request):
@@ -92,7 +92,7 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCaptchaMiniData(self, request):
@@ -115,7 +115,7 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCaptchaMiniDataSum(self, request):
@@ -138,7 +138,7 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCaptchaMiniOperData(self, request):
@@ -161,7 +161,7 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCaptchaMiniResult(self, request):
@@ -184,7 +184,7 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCaptchaMiniRiskResult(self, request):
@@ -207,7 +207,7 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCaptchaOperData(self, request):
@@ -230,7 +230,30 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeCaptchaRceResult(self, request):
+        """Rce融合验证核查验证码票据结果(Web及APP)
+
+        :param request: Request instance for DescribeCaptchaRceResult.
+        :type request: :class:`tencentcloud.captcha.v20190722.models.DescribeCaptchaRceResultRequest`
+        :rtype: :class:`tencentcloud.captcha.v20190722.models.DescribeCaptchaRceResultResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCaptchaRceResult", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCaptchaRceResultResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCaptchaResult(self, request):
@@ -253,7 +276,7 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCaptchaTicketData(self, request):
@@ -276,7 +299,7 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCaptchaUserAllAppId(self, request):
@@ -299,7 +322,30 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def GetRequestStatistics(self, request):
+        """查询单个CaptchaAppID验证的统计数据，包括：请求量、验证量、验证通过量、验证拦截量。
+
+        :param request: Request instance for GetRequestStatistics.
+        :type request: :class:`tencentcloud.captcha.v20190722.models.GetRequestStatisticsRequest`
+        :rtype: :class:`tencentcloud.captcha.v20190722.models.GetRequestStatisticsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetRequestStatistics", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetRequestStatisticsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetTicketStatistics(self, request):
@@ -322,7 +368,30 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def GetTotalRequestStatistics(self, request):
+        """查询全部验证的统计数据，包括：总请求量、总验证量、总验证通过量、总验证拦截量等数据。
+
+        :param request: Request instance for GetTotalRequestStatistics.
+        :type request: :class:`tencentcloud.captcha.v20190722.models.GetTotalRequestStatisticsRequest`
+        :rtype: :class:`tencentcloud.captcha.v20190722.models.GetTotalRequestStatisticsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetTotalRequestStatistics", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetTotalRequestStatisticsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetTotalTicketStatistics(self, request):
@@ -345,7 +414,7 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateCaptchaAppIdInfo(self, request):
@@ -368,4 +437,4 @@ class CaptchaClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
